==> jc-1.4.0.tar.gz: gnu/java/security/action/GetPropertyAction.h <==
// public class gnu.java.security.action.GetPropertyAction

// class file dependencies
// @dep_class ce302658cf9d799f gnu_java_security_action_GetPropertyAction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_action_GetPropertyAction_H_
#define _JC_gnu_java_security_action_GetPropertyAction_H_

// Forward structure declarations
struct _jc_gnu_java_security_action_GetPropertyAction$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_action_GetPropertyAction$sub_refs	_jc_gnu_java_security_action_GetPropertyAction$sub_refs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs	_jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$refs	_jc_gnu_java_security_action_GetPropertyAction$refs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$nonrefs	_jc_gnu_java_security_action_GetPropertyAction$nonrefs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$object	_jc_gnu_java_security_action_GetPropertyAction$object;

typedef const struct _jc_gnu_java_security_action_GetPropertyAction$vmethods	_jc_gnu_java_security_action_GetPropertyAction$vmethods;
typedef const struct _jc_gnu_java_security_action_GetPropertyAction$vtable	_jc_gnu_java_security_action_GetPropertyAction$vtable;
typedef const struct _jc_gnu_java_security_action_GetPropertyAction$vtype	_jc_gnu_java_security_action_GetPropertyAction$vtype;

// Constructors
extern void _jc_gnu_java_security_action_GetPropertyAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *);
extern void _jc_gnu_java_security_action_GetPropertyAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_security_action_GetPropertyAction$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_action_GetPropertyAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *);
extern struct _jc_gnu_java_security_action_GetPropertyAction$object *_jc_gnu_java_security_action_GetPropertyAction$method$setParameters$0ba13342f8899019(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *);
extern struct _jc_gnu_java_security_action_GetPropertyAction$object *_jc_gnu_java_security_action_GetPropertyAction$method$setParameters$6981f0059414c97e(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_security_action_GetPropertyAction$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$run$b190d7b16d5785b8;
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$setParameters$0ba13342f8899019;
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$setParameters$6981f0059414c97e;
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_action_GetPropertyAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *);
	struct _jc_gnu_java_security_action_GetPropertyAction$object	*(*setParameters$0ba13342f8899019)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *);
	struct _jc_gnu_java_security_action_GetPropertyAction$object	*(*setParameters$6981f0059414c97e)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *);
};

// Vtable
struct _jc_gnu_java_security_action_GetPropertyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_action_GetPropertyAction$vmethods	gnu_java_security_action_GetPropertyAction;
};

// Vtype
struct _jc_gnu_java_security_action_GetPropertyAction$vtype {
	_jc_type			type;
	_jc_gnu_java_security_action_GetPropertyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetPropertyAction$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_action_GetPropertyAction$refs {
    _jc_gnu_java_security_action_GetPropertyAction$sub_refs	gnu_java_security_action_GetPropertyAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_action_GetPropertyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs	gnu_java_security_action_GetPropertyAction;
};

// Object instance structure
struct _jc_gnu_java_security_action_GetPropertyAction$object {
	_jc_gnu_java_security_action_GetPropertyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_action_GetPropertyAction$vtype	*vtype;
	_jc_gnu_java_security_action_GetPropertyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_action_GetPropertyAction$vtype _jc_gnu_java_security_action_GetPropertyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_action_GetPropertyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_action_GetPropertyAction$class_object;

#endif	/* _JC_gnu_java_security_action_GetPropertyAction_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/action/GetPropertyAction.h <==
// public class gnu.java.security.action.GetPropertyAction

// class file dependencies
// @dep_class ce302658cf9d799f gnu_java_security_action_GetPropertyAction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_action_GetPropertyAction_H_
#define _JC_gnu_java_security_action_GetPropertyAction_H_

// Forward structure declarations
struct _jc_gnu_java_security_action_GetPropertyAction$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_action_GetPropertyAction$sub_refs	_jc_gnu_java_security_action_GetPropertyAction$sub_refs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs	_jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$refs	_jc_gnu_java_security_action_GetPropertyAction$refs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$nonrefs	_jc_gnu_java_security_action_GetPropertyAction$nonrefs;
typedef struct _jc_gnu_java_security_action_GetPropertyAction$object	_jc_gnu_java_security_action_GetPropertyAction$object;

typedef const struct _jc_gnu_java_security_action_GetPropertyAction$vmethods	_jc_gnu_java_security_action_GetPropertyAction$vmethods;
typedef const struct _jc_gnu_java_security_action_GetPropertyAction$vtable	_jc_gnu_java_security_action_GetPropertyAction$vtable;
typedef const struct _jc_gnu_java_security_action_GetPropertyAction$vtype	_jc_gnu_java_security_action_GetPropertyAction$vtype;

// Constructors
extern void _jc_gnu_java_security_action_GetPropertyAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_action_GetPropertyAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_action_GetPropertyAction$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_action_GetPropertyAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_action_GetPropertyAction$object *_jc_gnu_java_security_action_GetPropertyAction$method$setParameters$0ba13342f8899019(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_action_GetPropertyAction$object *_jc_gnu_java_security_action_GetPropertyAction$method$setParameters$6981f0059414c97e(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_action_GetPropertyAction$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$run$b190d7b16d5785b8;
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$setParameters$0ba13342f8899019;
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$setParameters$6981f0059414c97e;
extern _jc_method _jc_gnu_java_security_action_GetPropertyAction$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_action_GetPropertyAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_action_GetPropertyAction$object	*(*setParameters$0ba13342f8899019)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_action_GetPropertyAction$object	*(*setParameters$6981f0059414c97e)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_action_GetPropertyAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_action_GetPropertyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_action_GetPropertyAction$vmethods	gnu_java_security_action_GetPropertyAction;
};

// Vtype
struct _jc_gnu_java_security_action_GetPropertyAction$vtype {
	_jc_type			type;
	_jc_gnu_java_security_action_GetPropertyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetPropertyAction$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_action_GetPropertyAction$refs {
    _jc_gnu_java_security_action_GetPropertyAction$sub_refs	gnu_java_security_action_GetPropertyAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_action_GetPropertyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_action_GetPropertyAction$sub_nonrefs	gnu_java_security_action_GetPropertyAction;
};

// Object instance structure
struct _jc_gnu_java_security_action_GetPropertyAction$object {
	_jc_gnu_java_security_action_GetPropertyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_action_GetPropertyAction$vtype	*vtype;
	_jc_gnu_java_security_action_GetPropertyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_action_GetPropertyAction$vtype _jc_gnu_java_security_action_GetPropertyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_action_GetPropertyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_action_GetPropertyAction$class_object;

#endif	/* _JC_gnu_java_security_action_GetPropertyAction_H_ */
